package com.antmantech.admin.filter;

package ..deTemp.1731551840602;

import com.antmantech.client.SysAuthClient;
import com.antmantech.component.commons.utils.CurrentUserUtils;
import java.io.IOException;
import java.util.Set;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;
import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.core.RedisTemplate;

@Configuration
public class ConsumeSessionFilter implements Filter {
  private static final Logger log = LoggerFactory.getLogger(com.antmantech.admin.filter.ConsumeSessionFilter.class);
  
  public static final String ONLINE_USER_BETWEEN_TIME = "JET:SYSTEM:ONLINE_USER:BETWEEN_TIME";
  
  private ScheduledExecutorService executorService = Executors.newScheduledThreadPool(1);
  
  @Value("${jet.config.checkRequestIntervalTime:1800}")
  private Long checkRequestIntervalTime;
  
  @Resource
  private SysAuthClient sysAuthClient;
  
  @Autowired
  private RedisTemplate redisTemplate;
  
  public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
    if (request instanceof HttpServletRequest)
      try {
        HttpServletRequest httpServletRequest = (HttpServletRequest)request;
        Cookie[] cookies = httpServletRequest.getCookies();
        if (cookies != null)
          for (Cookie cookie : cookies) {
            String accessToken = cookie.getName();
            if ("token".equals(accessToken)) {
              this.redisTemplate.opsForHash().put("JET:SYSTEM:ONLINE_USER:BETWEEN_TIME", cookie.getValue(), Long.valueOf(System.currentTimeMillis()));
              this.redisTemplate.opsForHash().put("JET:SYSTEM:ONLINE_USER:COUNT", CurrentUserUtils.getCurrentUserId(), Long.valueOf(System.currentTimeMillis()));
              break;
            } 
          }  
      } catch (Exception e) {
        log.warn("过滤器异常---{}", e.getMessage());
      }  
    chain.doFilter(request, response);
  }
  
  private void checkRequestIntervalTime() {
    CompletableFuture.runAsync(() -> {
          Set keys = this.redisTemplate.opsForHash().keys("JET:SYSTEM:ONLINE_USER:BETWEEN_TIME");
          keys.forEach(());
        });
    CompletableFuture.runAsync(() -> {
          Set keys = this.redisTemplate.opsForHash().keys("JET:SYSTEM:ONLINE_USER:COUNT");
          keys.forEach(());
        });
  }
  
  @PostConstruct
  public void init() {
    this.checkRequestIntervalTime = Long.valueOf(this.checkRequestIntervalTime.longValue() * 1000L);
    this.executorService.scheduleWithFixedDelay(this::checkRequestIntervalTime, 60L, 10L, TimeUnit.SECONDS);
  }
}
